==> nextcloud-11.0.2.tgz: nextcloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
    "Please provide a valid app key and secret." : "Proszę podać prawidłowy klucz aplikacji i klucz sekretny.",
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Dropbox App Configuration" : "Konfiguracja aplikacji Dropbox",
    "Google Drive App Configuration" : "Konfiguracja aplikacji Google Drive",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Error configuring OAuth1" : "Błąd konfiguracji OAuth1",
    "Error configuring OAuth2" : "Błąd konfiguracji OAuth2",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Zgodność z kodowaniem Mac NFD (powolny)",
    "Admin defined" : "Zdefiniowane przez Administratora",
    "Saved" : "Zapisano",
    "Saving..." : "Zapisywanie...",
    "Save" : "Zapisz",
    "Empty response from the server" : "Puste odpowiedzi z serwera",
    "Couldn't access. Please logout and login to activate this mount point" : "Nie można uzyskać dostępu. Należy wylogować się i ponownie zalogować się, aby włączyć ten punkt montowania",
    "Couldn't get the information from the remote server: {code} {type}" : "Nie można otrzymać informacji od zdalnego serwera: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nie udało się uzyskać listy zewnętrznych punktów montowania: {type}",
    "There was an error with message: " : "Wystąpił błąd o treści:",
    "External mount error" : "Błąd przy montowaniu zewnętrznym",
    "external-storage" : "dysk zewnętrzny",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Nie udało się uzyskać listy punktów montowania dysku sieciowego z systemu Windows: puste odpowiedzi z serwera",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Niektóre skonfigurowane zewnętrzne punkty montowania są nie podłączone. Proszę kliknąć na czerwony rząd (y), aby uzyskać więcej informacji",
    "Please enter the credentials for the {mount} mount" : "Proszę wprowadzić poświadczenia dla {mount} montażu",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Credentials saved" : "Poświadczenia zapisane",
    "Credentials saving failed" : "Poświadczenia oszczędności nie powiodło się",
    "Credentials required" : "Wymagane poświadczenia",
    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
    "Invalid backend or authentication mechanism class" : "Nieprawidłowy mechanizm uwierzytelniania powrotu lub klasy",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Objectstore forbidden" : "Zabroniony obiekt sklepu",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie można używać powrotu \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie można używać mechanizmu uwierzytelnienia \"%s\"",
    "Unsatisfied backend parameters" : "Niepoprawne parametry backendu",
    "Unsatisfied authentication mechanism parameters" : "Niepoprawne parametry mechanizmu uwierzytelnienia",
    "Insufficient data: %s" : "Niewystarczające dane: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Magazyn o id \"%i\" nie jest edytowalny dla użytkowników",
    "Access key" : "Klucz dostępu",
    "Secret key" : "Sekretny klucz",
    "Builtin" : "Wbudowane",
    "None" : "Nic",
    "OAuth1" : "OAuth1",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nazwa dzierżawcy",
    "Identity endpoint URL" : "Adres końcówki identyfikującej",
    "Rackspace" : "Rackspace",
    "API key" : "Klucz API",
    "Global credentials" : "Globalne poświadczenia",
    "Log-in credentials, save in database" : "Poświadczenia logowania, zapisz w bazie danych",
    "Username and password" : "Nazwa użytkownika i hasło",
    "Log-in credentials, save in session" : "Poświadczenia logowania, zapisz w sesji",
    "User entered, store in database" : "Użytkownik wpisał, zapisz w bazie danych",
    "RSA public key" : "Klucz publiczny RSA",
    "Public key" : "Klucz publiczny",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kosz",
    "Hostname" : "Nazwa serwera",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Włącz SSL",
    "Enable Path Style" : "Włącz styl ścieżki",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Bezpieczny ftps://",
    "Google Drive" : "Dysk Google",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Udostępnij",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "OpenStack Object Storage" : "Magazyn obiektów OpenStack",
    "Service name" : "Nazwa serwisu",
    "Request timeout (seconds)" : "Limit czasu żądania (sekundy)",
    "External storages" : "Zewnętrzne zasoby dyskowe",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Obsługa cURL w PHP jest wyłączona lub nie jest zainstalowana. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby ją zainstalował.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Obsługa FTP w PHP jest wyłączona lub nie jest zainstalowana. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby ją zainstalował.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" nie jest zainstalowane. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby dokonał instalacji.",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "You can add external storages in the personal settings" : "W ustawieniach osobistych możesz dodać zewnętrzne magazyny przechowywania",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Enable sharing" : "Włącz udostępnianie",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "Folder name" : "Nazwa folderu",
    "Authentication" : "Poświadczenie",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Add storage" : "Dodaj zasoby dyskowe",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Allow users to mount external storage" : "Pozwól użytkownikom montować zewnętrzne zasoby dyskowe",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Nie udało się uzyskać informacje z serwera ownCloud: {code} {type}"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-12.0.2.tgz: nextcloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
    "Please provide a valid app key and secret." : "Proszę podać prawidłowy klucz aplikacji i klucz sekretny.",
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storages" : "Magazyny zewnętrzne",
    "Dropbox App Configuration" : "Konfiguracja aplikacji Dropbox",
    "Google Drive App Configuration" : "Konfiguracja aplikacji Google Drive",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Error configuring OAuth1" : "Błąd konfiguracji OAuth1",
    "Error configuring OAuth2" : "Błąd konfiguracji OAuth2",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Zgodność z kodowaniem Mac NFD (powolny)",
    "Admin defined" : "Zdefiniowane przez Administratora",
    "Saved" : "Zapisano",
    "Saving..." : "Zapisywanie...",
    "Save" : "Zapisz",
    "Empty response from the server" : "Puste odpowiedzi z serwera",
    "Couldn't get the information from the remote server: {code} {type}" : "Nie można otrzymać informacji od zdalnego serwera: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nie udało się uzyskać listy zewnętrznych punktów montowania: {type}",
    "There was an error with message: " : "Wystąpił błąd o treści:",
    "External mount error" : "Błąd przy montowaniu zewnętrznym",
    "external-storage" : "magazyn zewnętrzny",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Niektóre skonfigurowane zewnętrzne punkty montowania są nie podłączone. Proszę kliknąć na czerwony rząd (y), aby uzyskać więcej informacji",
    "Please enter the credentials for the {mount} mount" : "Proszę wprowadzić poświadczenia dla {mount} montażu",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Credentials saved" : "Poświadczenia zapisane",
    "Credentials saving failed" : "Poświadczenia oszczędności nie powiodło się",
    "Credentials required" : "Wymagane poświadczenia",
    "Storage with ID \"%d\" not found" : "Nie znaleziono magazynu o ID \"%d\"",
    "Invalid backend or authentication mechanism class" : "Nieprawidłowy mechanizm uwierzytelniania powrotu lub klasy",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Objectstore forbidden" : "Zabroniony obiekt sklepu",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie można używać powrotu \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie można używać mechanizmu uwierzytelnienia \"%s\"",
    "Unsatisfied backend parameters" : "Niepoprawne parametry backendu",
    "Unsatisfied authentication mechanism parameters" : "Niepoprawne parametry mechanizmu uwierzytelnienia",
    "Insufficient data: %s" : "Niewystarczające dane: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Magazyn o ID \"%d\" nie może być edytowany przez użytkownika",
    "Access key" : "Klucz dostępu",
    "Secret key" : "Sekretny klucz",
    "Builtin" : "Wbudowane",
    "None" : "Nic",
    "OAuth1" : "OAuth1",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nazwa dzierżawcy",
    "Identity endpoint URL" : "Adres końcówki identyfikującej",
    "Rackspace" : "Rackspace",
    "API key" : "Klucz API",
    "Global credentials" : "Globalne poświadczenia",
    "Log-in credentials, save in database" : "Poświadczenia logowania, zapisz w bazie danych",
    "Username and password" : "Nazwa użytkownika i hasło",
    "Log-in credentials, save in session" : "Poświadczenia logowania, zapisz w sesji",
    "User entered, store in database" : "Użytkownik wpisał, zapisz w bazie danych",
    "RSA public key" : "Klucz publiczny RSA",
    "Public key" : "Klucz publiczny",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kosz",
    "Hostname" : "Nazwa serwera",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Włącz SSL",
    "Enable Path Style" : "Włącz styl ścieżki",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Bezpieczny ftps://",
    "Google Drive" : "Dysk Google",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Udostępnij",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "OpenStack Object Storage" : "Magazyn obiektów OpenStack",
    "Service name" : "Nazwa serwisu",
    "Request timeout (seconds)" : "Limit czasu żądania (sekundy)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Obsługa cURL w PHP jest wyłączona lub nie jest zainstalowana. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby ją zainstalował.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Obsługa FTP w PHP jest wyłączona lub nie jest zainstalowana. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby ją zainstalował.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" nie jest zainstalowane. Zamontowanie %s jest niemożliwe. Proszę poprosić swojego administratora systemu, żeby dokonał instalacji.",
    "External storage support" : "Wsparcie dla zewnętrznego magazynu",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "You can add external storages in the personal settings" : "W ustawieniach osobistych możesz dodać zewnętrzne magazyny przechowywania",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Enable sharing" : "Włącz udostępnianie",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "Folder name" : "Nazwa folderu",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Authentication" : "Poświadczenie",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Add storage" : "Dodaj zewnętrzne magazyny",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Allow users to mount external storage" : "Pozwól użytkownikom montować zewnętrzne zasoby dyskowe",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe",
    "Storage with id \"%i\" not found" : "Magazyn o ID \"%i\" nie został znaleziony",
    "Storage with id \"%i\" is not user editable" : "Magazyn o ID \"%i\" nie może być edytowany przez użytkowników"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
